@@ -1,7 +1,22 @@
 from rest_framework.permissions import BasePermission, SAFE_METHODS
 
 
-class AbstractUserGetCreatePermissions(BasePermission):
+class UNICMSSafePermissions(BasePermission):
+    """
+    """
+
+    def has_permission(self, request, view):
+
+        method = request.method
+        if method in SAFE_METHODS:
+            return True
+
+        user = request.user
+        if user.is_staff: return True
+        if user.is_superuser: return True
+
+
+class UNICMSUserGetCreatePermissions(BasePermission):
     """
     """
 
@@ -19,7 +34,7 @@ class AbstractUserGetCreatePermissions(BasePermission):
         abstract = True
 
 
-class CarouselGetCreatePermissions(AbstractUserGetCreatePermissions):
+class CarouselGetCreatePermissions(UNICMSUserGetCreatePermissions):
     """
     """
 
@@ -27,7 +42,15 @@ class CarouselGetCreatePermissions(AbstractUserGetCreatePermissions):
         return super().has_permission(request, view, 'cmscarousels', 'carousel')
 
 
-class PublicationGetCreatePermissions(AbstractUserGetCreatePermissions):
+class ContactGetCreatePermissions(UNICMSUserGetCreatePermissions):
+    """
+    """
+
+    def has_permission(self, request, view):
+        return super().has_permission(request, view, 'cmscontacts', 'contact')
+
+
+class PublicationGetCreatePermissions(UNICMSUserGetCreatePermissions):
     """
     """
 
@@ -35,7 +58,7 @@ class PublicationGetCreatePermissions(AbstractUserGetCreatePermissions):
         return super().has_permission(request, view, 'cmspublications', 'publication')
 
 
-class MediaGetCreatePermissions(AbstractUserGetCreatePermissions):
+class MediaGetCreatePermissions(UNICMSUserGetCreatePermissions):
     """
     """
 
@@ -43,7 +66,7 @@ class MediaGetCreatePermissions(AbstractUserGetCreatePermissions):
         return super().has_permission(request, view, 'cmsmedias', 'media')
 
 
-class MediaCollectionGetCreatePermissions(AbstractUserGetCreatePermissions):
+class MediaCollectionGetCreatePermissions(UNICMSUserGetCreatePermissions):
     """
     """
 
@@ -51,7 +74,7 @@ class MediaCollectionGetCreatePermissions(AbstractUserGetCreatePermissions):
         return super().has_permission(request, view, 'cmsmedias', 'mediacollection')
 
 
-class MenuGetCreatePermissions(AbstractUserGetCreatePermissions):
+class MenuGetCreatePermissions(UNICMSUserGetCreatePermissions):
     """
     """
 
