@@ -62,6 +62,14 @@ class CarouselAPIUnitTest(TestCase):
         res = req.get(url, content_type='application/json',)
         assert isinstance(res.json(), dict)
 
+        # redis lock set
+        ct = ContentType.objects.get_for_model(carousel)
+        data = {'content_type_id': ct.pk,
+                'object_id': carousel.pk}
+        res = req.post(url, data,
+                       content_type='application/json', follow=1)
+        assert isinstance(res.json(), dict)
+
         # GET, patch, put, delete
         url = reverse('unicms_api:carousel', kwargs={'pk': carousel.pk})
 
@@ -108,8 +116,19 @@ class CarouselAPIUnitTest(TestCase):
         assert carousel.name == 'carousel api-test'
         assert not carousel.is_active
 
+        # GET SelectField Options
+        url = reverse('unicms_api:carousel-options')
+        res = req.get(url)
+        assert isinstance(res.json(), dict)
+
+        url = reverse('unicms_api:carousel-option',
+                      kwargs={'pk': carousel.pk})
+        res = req.get(url)
+        assert isinstance(res.json(), dict)
+
         # DELETE
         # user hasn't permission
+        url = reverse('unicms_api:carousel', kwargs={'pk': carousel.pk})
         req.force_login(user2)
         res = req.delete(url)
         assert res.status_code == 403
