@@ -2,8 +2,7 @@ from django.conf import settings
 from django.shortcuts import redirect
 from django.urls import path, re_path
 
-from cms.contexts.views import pagePreview
-from . views import cms_dispatch
+from . views import *
 
 urlpatterns = []
 
@@ -14,6 +13,7 @@ CMS_PATH_PREFIX = getattr(settings, 'CMS_PATH_PREFIX', '')
 if CMS_PATH_PREFIX:
     urlpatterns += path('', lambda req: redirect(f'/{CMS_PATH_PREFIX}')),
 
+urlpatterns += re_path(r'^' + CMS_PATH_PREFIX + 'sitemap.xml$', unicms_sitemap, name='unicms_sitemap'),
 urlpatterns += re_path(f'{CMS_PATH_PREFIX}.*', cms_dispatch, name='cms_dispatch'),
 
 urlpatterns += path('pages/<int:page_id>/preview/', pagePreview, name='page-preview'),
