@@ -266,6 +266,15 @@ class PageUnitTest(TestCase):
         lm = load_contact(**data)
         assert lm
 
+        contact = ContactUnitTest.create_contact()
+        data = dict(context=template_context,
+                    section='1-right-b',
+                    template='that.html',
+                    contact_id=contact.pk)
+
+        lm2 = load_contact(**data)
+        assert lm2
+
 
     # templatetag
     @classmethod
@@ -671,6 +680,13 @@ class PageUnitTest(TestCase):
         assert ic
 
 
+    def test_unicms_sitemap(self):
+        obj = self.create_page(webpath_path='/')
+        url = reverse('unicms:unicms_sitemap')
+        res = self.client.get(url)
+        assert res.status_code == 200
+
+
     # templatetag
     # @classmethod
     # def test_load_current_item_from_menu(cls):
