@@ -72,8 +72,12 @@ class AbstractPublication(TimeStampedModel, ActivableModel):
     )
     content = models.TextField(default='', blank=True, help_text=_('Content'))
     content_type = models.CharField(choices=CONTENT_TYPES, max_length=33, default='html')
+    preview_image = models.ForeignKey(Media, null=True, blank=True,
+                                      on_delete=models.PROTECT,
+                                      related_name="preview_image")
     presentation_image = models.ForeignKey(Media, null=True, blank=True,
-                                           on_delete=models.PROTECT)
+                                           on_delete=models.PROTECT,
+                                           related_name="presentation_image")
     # state = models.CharField(choices=PAGE_STATES,
     # max_length=33,
     # default='draft')
@@ -115,9 +119,11 @@ class Publication(AbstractPublication, CreatedModifiedBy, AbstractLockable):
         return PublicationLocalization.objects.filter(publication=self,
                                                       is_active=True)
 
-    def image_url(self):
+    def image_url(self, force_main=False):
         image_path = ''
-        if self.presentation_image:
+        if self.preview_image and not force_main:
+            image_path = self.preview_image.file
+        elif self.presentation_image:
             image_path = self.presentation_image.file
         else: # pragma: no cover
             categories = self.category.all()
@@ -128,6 +134,19 @@ class Publication(AbstractPublication, CreatedModifiedBy, AbstractLockable):
         return sanitize_path(f'{settings.MEDIA_URL}/{image_path}') \
             if image_path else image_path
 
+    def image_main_url(self):
+        return self.image_url(force_main=True)
+
+    def image_title(self):
+        if self.preview_image: return self.preview_image.title
+        if self.presentation_image: return self.presentation_image.title
+        return self.title
+
+    def image_description(self):
+        if self.preview_image: return self.preview_image.description
+        if self.presentation_image: return self.presentation_image.description
+        return self.subheading
+
     @property
     def categories(self):
         return self.category.all()
@@ -140,14 +159,32 @@ class Publication(AbstractPublication, CreatedModifiedBy, AbstractLockable):
         return [i for i in related]
 
     @property
-    def related_contexts(self):
-        return PublicationContext.objects.filter(publication=self,
-                                                 webpath__is_active=True)
+    def related_contexts(self, unique_webpath=True, published=True):
+        contexts = PublicationContext.objects.select_related('webpath')\
+                                             .filter(publication=self,
+                                                     is_active=True,
+                                                     webpath__is_active=True)
+        if published:
+            now = timezone.localtime()
+            contexts = contexts.filter(date_start__lte=now,
+                                       date_end__gte=now)
+        if not unique_webpath: return contexts
+        webpaths = []
+        unique_contexts = []
+        for context in contexts:
+            if context.webpath in webpaths: continue
+            webpaths.append(context.webpath)
+            unique_contexts.append(context)
+        return unique_contexts
 
     @property
     def first_available_url(self):
+        now = timezone.localtime()
         pubcontx = PublicationContext.objects.filter(publication=self,
-                                                     webpath__is_active=True)
+                                                     is_active=True,
+                                                     webpath__is_active=True,
+                                                     date_start__lte=now,
+                                                     date_end__gte=now)
         if pubcontx.exists():
             return pubcontx.first().url
 
@@ -333,6 +370,7 @@ class PublicationContext(TimeStampedModel, ActivableModel,
 
     class Meta:
         verbose_name_plural = _("Publication Contexts")
+        ordering = ['webpath__fullpath', 'order']
 
     @property
     def path_prefix(self):
@@ -358,6 +396,9 @@ class PublicationContext(TimeStampedModel, ActivableModel,
         url = f'{self.webpath.get_full_path()}{self.path_prefix}/{self.publication.slug}'
         return sanitize_path(url)
 
+    def get_absolute_url(self):
+        return self.url
+
     @property
     def name(self):
         return self.publication.title
@@ -371,7 +412,7 @@ class PublicationContext(TimeStampedModel, ActivableModel,
         return result
 
     @property
-    def is_publicated(self) -> bool:
+    def is_published(self) -> bool:
         now = timezone.localtime()
         return self.date_start <= now and self.date_end >= now
 
