@@ -49,19 +49,21 @@ class PublicationSerializer(TaggitSerializer,
 
     def to_representation(self, instance):
         data = super().to_representation(instance)
+        preview_image = MediaSerializer(instance.preview_image)
+        data['preview_image'] = preview_image.data
         presentation_image = MediaSerializer(instance.presentation_image)
         data['presentation_image'] = presentation_image.data
         categories = []
         for category in instance.category.all():
             categories.append(CategorySerializer(category).data)
-        data['category'] = categories
+        data['category_data'] = categories
         data['full_name'] = instance.__str__()
         return data
 
     class Meta:
         model = Publication
         fields = '__all__'
-        read_only_fields = ('is_active', 'created_by', 'modified_by', 'content_type')
+        read_only_fields = ('created_by', 'modified_by', 'content_type')
 
 
 class PublicationSelectOptionsSerializer(serializers.ModelSerializer):
